# -*- coding: utf-8 -*-
"""
cyipopt: Python wrapper for the Ipopt optimization package, written in Cython.

Copyright (C) 2012-2015 Amit Aides
Copyright (C) 2015-2017 Matthias Kümmerer
Copyright (C) 2017-2021 cyipopt developers

License: EPL 1.0
"""

from __future__ import absolute_import

from ipopt_wrapper import *
from .ipopt_wrapper import *
from .scipy_interface import *
from .version import __version__
